# Roadmap to 1.0

## 0.1.0

- Barebones header, footer, search.

- 3 column layout
  - Site Navigation (with affix)
  - Content
  - Page Navigation (with affix + scrollspy)
- Responsive collapsing!
- Sticky header element

- Vanilla CSS affix: https://codepen.io/ncerminara/pen/eKNROb
- Vanilla JS scrollspy: https://codepen.io/zchee/pen/ogzvZZ

## 0.2.0

- Add JS and make sidebars nicer
- Better header
- Better footer

## 0.3.0

- Sidebar: scroll-height adjusting
- Left Sidebar: collapsing elements!
- Work on docs/demo/paragraph

## 0.4.0

- Work on docs/demo/*

## 0.5.0

- Better search page + in header
- top-of-page announcements

## 0.6.0

- Pay down debt.
- Polish Design!

## 0.7.0

- Work on mobile support for Table-of-Contents sidebar.

## 0.8.0

- sphinx-tabs integration!
